ActionResult

Enum ActionResult 

pub enum ActionResult {
    Done,
    ParentActionRequest(Command, Context),
    Result(Command, Context),
    Custom(Box<dyn Debug>),
}
ActionResult stores result of action. Commandのアクション結果を格納し、runの結果として返却するためのenum。

Variants



Done

Done shows that action is done.



ParentActionRequest(Command, Context)

ParentActionRequest shows that action requested to show help. It is mainly used for help command.



Result(Command, Context)

Shows return Context, reached Command and Action as result for parse and run. By using this, it is possible to get parse result and run action without keeping command instances of tree in memory.



Custom(Box<dyn Debug>)

Custom result(can have Box including dyn Debug).

Implementations

Source

impl ActionResult

pub fn is_done(&self) -> bool

Returns true if self is done.